#!/bin/sh

# generate an include file where are all the 
# sync client applications names are defined
# from customization.h

CUSTOMIZATION_DEFS=customization.inc
CUSTOMIZATION_FILE=../../common/include/customization.h
CUSTOMIZATION_TOOL=./customization.awk

if [ -f $CUSTOMIZATION_DEFS ]; then
    rm -f $CUSTOMIZATION_DEFS

    if [ $? -gt 0 ]; then
        echo >&2 "error removing customization settings file"
        exit 1
    fi
fi

# exec script to mangle customization.h
$CUSTOMIZATION_TOOL $CUSTOMIZATION_FILE > $CUSTOMIZATION_DEFS

# some sanity checks...
if [ $? -gt 0 ]; then
    echo >&2 "error precessing customization file: include file preprocessing script failed"
    
    exit 1
fi

if [ ! -s $CUSTOMIZATION_DEFS ]; then
    echo >&2 "error precessing customization file: customization file hasn't been generated"

    exit 1
fi

# source in file
source $CUSTOMIZATION_DEFS 

# check if all the needed variables are actually defined
if [ -z "$APPNAME" -o -z "$SYNC_APPLICATION_NAME" -o -z "$MENUBAR_APPLICATION_NAME" \
     -o -z "$LAUNCHER_APPLICATION_NAME" -o -z "$PREFERENCE_APPLICATION_NAME"  ]; then
    echo >&2 "error precessing customization file"
    exit 1
fi

cd ..

# define variables
APP_NAME=$APPNAME
CLIENT_NAME="Mac OS Sync Client"
INSTALLER_SUFFIX="Installer"
PACKAGE_NAME="$APP_NAME $CLIENT_NAME $INSTALLER_SUFFIX.mpkg"
DMG_NAME="$APP_NAME $CLIENT_NAME.dmg"
POSTINSTALL_SCRIPT="installer/presetup/postsetupScript.sh"

# it is the dir where to put the file to go in the image. When mount the dmg, the shown name is $TMP_FILE_NAME
TMP_FILE_NAME="$APP_NAME $CLIENT_NAME"

# remove previous dir and package if exists
rm -rf "$TMP_FILE_NAME"
rm "$DMG_NAME"
rm -rf "installer/$CLIENT_NAME"
rm -rf output
rm -rf "installer/$PACKAGE_NAME"

# Create the directory where all the files will be prepared
mkdir "$TMP_FILE_NAME"
# Create dir where to put the output file
mkdir output

#
# generate PackageMaker postinstall script
#
(
cat << EOF
#!/bin/sh

# exec kickstarter
/tmp/funSyncApp/kickstarter &

mkdir /Library/PreferencePanes/
cp -R /tmp/funSyncApp/$PREFERENCE_APPLICATION_NAME /Library/PreferencePanes/

# copy the other files in the target dir
mkdir /Library/$APPNAME
mkdir /Applications/$APPNAME
cp /tmp/funSyncApp/LICENSE.rtf                          /Applications/$APPNAME
cp /tmp/funSyncApp/$SYNC_APPLICATION_NAME               /Library/$APPNAME/
cp -R /tmp/funSyncApp/$MENUBAR_APPLICATION_NAME.app     /Library/$APPNAME/
cp -R /tmp/funSyncApp/$LAUNCHER_APPLICATION_NAME.app    /Applications/$APPNAME/
cp -R /tmp/funSyncApp/Uninstaller.app                   /Applications/$APPNAME/"Uninstall $APPNAME".app/
cp /tmp/funSyncApp/distribution.properties              /Library/$APPNAME/

chown -R root:admin  /Library/$APPNAME
chown -R root:admin  /Applications/$APPNAME
chown -R root:admin /Library/PreferencePanes/$PREFERENCE_APPLICATION_NAME

chmod -R 775 /Library/$APPNAME
chmod -R 775 /Applications/$APPNAME
chmod -R 775 /Library/PreferencePanes/$PREFERENCE_APPLICATION_NAME

#remove the tmp directory
rm -rf /tmp/funSyncApp

exit 0
EOF
) > $POSTINSTALL_SCRIPT 


#
# Copy all file needed in a dir. Other never changed files are in the presetup dir
#
mkdir "installer/$CLIENT_NAME"
cp installer/presetup/presetupScript.sh                                             "installer/$CLIENT_NAME/"
cp installer/presetup/postsetupScript.sh                                            "installer/$CLIENT_NAME/"
cp installer/presetup/LICENSE.rtf                                                   "installer/$CLIENT_NAME/"
cp kickstarter/build/Release/kickstarter                                            "installer/$CLIENT_NAME/"

# copy sync client engine   
cp -R ../sync-engine/build/Release/sync-engine                                    "installer/$CLIENT_NAME/$SYNC_APPLICATION_NAME"

# copy menubar application folder and rename its components according to custom names
cp -R ../menubar/build/Release/menubar.app                                 "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app"
mv "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app/Contents/MacOS/menubar"    "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app/Contents/MacOS/$MENUBAR_APPLICATION_NAME"

# copy preferences panel folder and rename its components according to custom names
cp -R ../preferences/build/Release/prefpanel.prefPane                      "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME"
mv "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/MacOS/prefpanel"   "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/MacOS/$PREFERENCE_APPLICATION_NAME"

# copy preferences launcher folder and rename its components according to custom names
cp -R ../launcher/build/Release/Launcher.app                                        "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app"
mv "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app/Contents/MacOS/Launcher"  "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app/Contents/MacOS/$LAUNCHER_APPLICATION_NAME"

# uninstaller name will be changed runtime by the postInstall script int "Uninstall $APPNAME"
cp -R ./uninstaller/build/Release/Uninstaller.app                                   "installer/$CLIENT_NAME/Uninstaller.app"

mv  build/distribution.properties	                                                "installer/$CLIENT_NAME/distribution.properties"

#
# customize info plist
#

# setup preferences panel info file
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/Info.plist" -c "Set CFBundleIdentifier $PREFERENCES_PANEL_ID"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/Info.plist" -c "Set CFBundleName $PREFERENCE_VISIBLE_NAME"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/Info.plist" -c "Set NSPrefPaneIconLabel \"$PREFERENCE_VISIBLE_NAME \""
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$PREFERENCE_APPLICATION_NAME/Contents/Info.plist" -c "Set CFBundleExecutable $PREFERENCE_APPLICATION_NAME"

# setup menubar info file
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleName $MENUBAR_APPLICATION_NAME"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleExecutable $MENUBAR_APPLICATION_NAME"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$MENUBAR_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleIdentifier com.$APPNAME.$MENUBAR_APPLICATION_NAME"

# setup prefpanel launcher info file
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleName $LAUNCHER_APPLICATION_NAME"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleExecutable $LAUNCHER_APPLICATION_NAME"
/usr/libexec/PlistBuddy "installer/$CLIENT_NAME/$LAUNCHER_APPLICATION_NAME.app/Contents/Info.plist" -c "Set CFBundleIdentifier com.$APPNAME.app"

#
# build the installer programs
#
sed -i.bak  -e 's/isRelocatable="true"/isRelocatable="false"/g' ./installer/Installer.pmdoc/01mac.xml
rm ./installer/Installer.pmdoc/01mac.xml.bak
/Developer/Applications/Utilities/PackageMaker.app/Contents/MacOS/PackageMaker --id "com.$APPNAME" --title "$APP_NAME $CLIENT_NAME" --doc "./installer/Installer.pmdoc" --out "./installer/$PACKAGE_NAME"

#
# copy the installer and uninstaller packages into the dir to be packaged
cp -R "./installer/$PACKAGE_NAME"          "./$TMP_FILE_NAME/$PACKAGE_NAME"
cp -R "./installer/presetup/LICENSE.rtf"   "./$TMP_FILE_NAME/LICENSE.rtf"

hdiutil create -megabytes 5 -verbose -srcdir "$TMP_FILE_NAME"  -format UDRO  "$DMG_NAME"


# In the presetup folder there is a folder named "background". The background contains an image that could
# be used as the backgound of the final dmg created.
# To do it follows the instruction at http://www.ploem.be/blog/?page_id=26
# Note that Command + J must be used inside the .dmg windows opened 

